#
# spec file for package librep
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007 John Harper <john@dcs.warwick.ac.uk>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           librep
Version:        0.92.5
Release:        lp150.1.26
Summary:        Implementation of rep, a lisp dialect
License:        GPL-2.0+
Group:          Development/Languages/Scheme
Url:            http://sawfish.wikia.com/wiki/Librep
Source:         http://download.tuxfamily.org/librep/%{name}_%{version}.tar.xz
BuildRequires:  chrpath
BuildRequires:  emacs-nox
BuildRequires:  fdupes
BuildRequires:  gdbm-devel
BuildRequires:  gmp-devel
BuildRequires:  libffi-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  readline-devel
%if 0%{?suse_version} <= 1210
BuildRequires:  xz
%endif
%if 0%{suse_version} > 1220
BuildRequires:  makeinfo
%endif

Requires(pre):  %install_info_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# PATCH-FEATURE-OPENSUSE 0001-install-byte-compiled-emacs-lisp.patch toganm@opensuse.org
Patch1:         0001-install-byte-compiled-emacs-lisp.patch
# PATCH-FIX_UPSTREAM 0001-string-to-number.patch toganm@opensuse.org use newer emacs functions
Patch2:         0001-string-to-number.patch
# PATCH-FEATURE-OPENSUSE toganm@opensuse.org remove builddate to prevent unnecessary builds
Patch3:         librep-remove-build_date.patch

%description
Librep is a shared library implementing a Lisp dialect that is
lightweight, reasonably fast, and highly extensible. It contains an
interpreter, byte-code compiler and virtual machine. Applications may
use the interpreter as an extension language, or it may be used for
standalone scripts.

Rep was originally inspired by Emacs Lisp. However one of the main
deficiencies of elisp -- the reliance on dynamic scope -- has been
removed. Also, rep only has a single namespace for symbols.

%package -n librep16
Summary:        Implementation of rep, a lisp dialect - Libraries
Group:          Development/Languages/Scheme

%description -n librep16
Librep is a shared library implementing a Lisp dialect that is
lightweight, reasonably fast, and highly extensible. It contains an
interpreter, byte-code compiler and virtual machine. Applications may
use the interpreter as an extension language, or it may be used for
standalone scripts.

Rep was originally inspired by Emacs Lisp. However one of the main
deficiencies of elisp -- the reliance on dynamic scope -- has been
removed. Also, rep only has a single namespace for symbols.

%package devel
Summary:        Implementation of rep, a lisp dialect - Development Files
Group:          Development/Languages/Scheme
Requires:       %{name} = %{version}
Requires:       librep16 = %{version}

%description devel
Librep is a shared library implementing a Lisp dialect that is
lightweight, reasonably fast, and highly extensible. It contains an
interpreter, byte-code compiler and virtual machine. Applications may
use the interpreter as an extension language, or it may be used for
standalone scripts.

Rep was originally inspired by Emacs Lisp. However one of the main
deficiencies of elisp -- the reliance on dynamic scope -- has been
removed. Also, rep only has a single namespace for symbols.

%prep
%setup -q -n %{name}_%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
export CFLAGS="%{optflags} -D_GNU_SOURCE -fno-strict-aliasing -fgnu89-inline"
export CXXFLAGS="$CFLAGS"
export CPPFLAGS="$CFLAGS"

%configure --disable-static --with-readline --enable-shared
make %{?_smp_mflags}

%install
%make_install
chrpath --delete %{buildroot}%{_bindir}/rep
# note: we need to keep some .la files, see http://mail.gnome.org/archives/sawfish-list/2008-October/msg00001.html
# Nevertheless I am removing them if anything fails then comment below
find %{buildroot}%{_libdir} -name \*.la -exec rm '{}' \;

%fdupes %{buildroot}%{_libdir}/rep
%fdupes %{buildroot}%{_datadir}/rep
%fdupes %{buildroot}%{_libexecdir}/rep/%{version}

%clean
rm -rf %{buildroot}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%post -n librep16 -p /sbin/ldconfig

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun -n librep16 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog COPYING MAINTAINERS README TODO
%{_bindir}/rep
%{_bindir}/rep-remote
%doc %{_mandir}/man?/rep.*
%doc %{_mandir}/man?/rep-remote.*
%{_datadir}/rep
%{_libdir}/rep/
%{_infodir}/%{name}.info.gz
%{_datadir}/emacs/site-lisp/rep-*.elc

%files -n librep16
%defattr(-,root,root)
%{_libdir}/librep.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/rep-xgettext
%{_bindir}/repdoc
%doc %{_mandir}/man?/rep-xgettext.*
%doc %{_mandir}/man?/repdoc.*
%{_libdir}/librep.so
%{_includedir}/rep/
%{_libdir}/pkgconfig/librep.pc

%changelog
* Mon Jun 22 2015 antoine.belvire@laposte.net
- Fix compilation with GCC 5: add -fgnu89-inline to CFLAGS.
* Fri Mar 27 2015 toganm@opensuse.org
- Update to 0.92.5
  * Assume stack-direction 'downwards' for all sparc, hppa, mips,
    mipsel, ia64 and alpha variants (fixes compilation)
  * Fix compilation due to bug in libtool 2.0+ if /bin/sh is not
    /bin/bash
  * rules.mk clean-up :
    + Variables that depend on prefix should not be recursive
    + Don't set prefix, datadir, libdir, datarootdir and repdir
    + Use pkg-config to get the absolute path for repcommonexecdir
  * Update .gitignore
  * Update config.sub to 2014-09-11 from autoconf
- Remove backported patch
  0002-Assume-stack-direction-downwards-for-all-sparc-hppa-.patch
* Mon Sep  1 2014 toganm@opensuse.org
- Update to 0.92.4
  * Fix building librep on ARM
- Packaging changes
  * Backported from git
    0002-Assume-stack-direction-downwards-for-all-sparc-hppa-.patch
  * Removed librep-armthumb.patch
* Tue Jan  8 2013 toganm@opensuse.org
- Update to 0.92.3
  * More entities support for xml-reader (gt, umlauts, esszett)
  * Fix address of FSF in all files [Togan Muftuoglu]
  * Assume stack-direciton `downwards' for all ppc and s390 variants
    [Kimb B. Heino]
  * Updated `install-sh' to version 2011-01-19.21.
  * Added `program-exists-p' [Mark Triggs]
- Removed 0001-fix-incorrect-fsf-address.patch as it is now upstream
* Mon Dec 17 2012 dvaleev@suse.com
- fix sed rule in the spec file for stack direction fix
* Tue Nov 27 2012 crrodriguez@opensuse.org
- librep-armthumb.patch: fix build in arm
* Sun Oct 28 2012 toganm@opensuse.org
- Add the following patches
  * 0001-string-to-number.patch replaces depreciated emacs
    function
  * librep-remove-build_date.patch remove build date to prevent
    unnecessary builds
* Thu Sep 13 2012 toganm@opensuse.org
- add makeinfo to buildrequires if > 12.2
* Mon Jul  2 2012 toganm@opensuse.org
- Update to 0.92.2.1 (no changelog difference as previous release)
  * spec cleanup
    + BuildRequires xz if openSUSE 12.1 or older
    + 0001-fix-incorrect-fsf-address.patch
    + 0001-install-byte-compiled-emacs-lisp to provide byte
    compiled rep-debugger (adds emacs-nox to build requirements)
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 0.92.2:
  + Assume stack-direction `downwards' for x86_64. Self-detection
    doesn't work with gcc >= 4.7.0
  + read_line no longer aborts at 400 characters
- Changes from version 0.92.1b:
  + Fixed a bug in librep.pc
- Changes from version 0.92.1:
  + Added `positon' meta-function
  + Imported utility-functions from Sawfish: `beautify-symbol',
    `remove-newlines', `option-index' and `string->symbol'.
  + Build fixes.
- Changes from version 0.92.0:
  + Bumped soname to 16.0.0
  + Make librep loading shared-objects, rather than
    libtool-archives
  + Removed architecture and version from installation paths
- Changes from version 0.91.1:
  + New `rep.ffi.util' module
  + New functions:
  - `function-name' returns the name of the function object.
  - `remove-hook-by-name' removes functions from a hook by their
    name.
  + Minor bugfix: `remove-hook' used to emit an error if the hook
    was unbound, but it's fixed.
  + Documentation improvements.
  + Build fixes.
- Changes from version 0.91.0:
  + Halfway improved `debug-on-error' and `backtrace-on-error'
  + When you evaluate a closure interactively, the module it
    belongs to is printed, too.
  + Improved functions' docstring support
  + New function `subr-structure'
  + `define-special-variable' is replaced by `defvar-setq'
  + Major documentation revision
- Changes from version 0.90.6:
  + renamed `file-uid-p' to `file-uid' and `file-gid-p' to
    `file-gid'
  + Process execution failure emits better message.
  + Minor doc improvements.
- Rename librep9 to librep16, following upstream soversion bump.
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.90.5:
  + Byte compiler bugfix in docstring loss
  + Remove dlmalloc implementation, that was disabled anyway
  + Remove alloca/memcmp implementation and use libcs instead
  + Install headers to $includedir/rep/ instead of $includedir/
  + Autotools improvements (Makefile, autogen.sh & Co.)
  + Added file-gid-p, file-uid-p functions to get the gid/uid of a
    file
- Remove call to automake: this tarball is fine.
* Sat Dec 19 2009 vuntz@opensuse.org
- Update to version 0.90.4:
  + Fixes fror OpenBSD.
  + Build system fixes.
- Call automake because of missing config.sub in tarball.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 0.90.3:
  + Added `file-executable-p' function
  + Improved spec-file
  + Improved ebuild
  + Fallback check for ffi, if there's no libffi.pc
  + Removed rep-config script (use librep.pc instead)
  + Added man-pages for `rep', `repdoc', `rep-remote' and
    `rep-xgettext'
  + Added debian packaging scripts based on the official ones
- Drop librep-no-ffi-pc.patch: fixed upstream.
- Remove autoconf call.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.90.2:
  + Fixed a major defunct with prin1 + utf8
  + Fixed descriptions of formats %%s and %%S in streams.c
- Changes from version 0.90.1:
  + Properly terminate the rep interpreter
  + Use readline history in interactive mode
  + Tar file-handler does now support XZ compressed tarballs
  + Tar file-handler does now support LZMA compressed tarballs
  + Improved regex for parsing tar output in the file-handler
  + We do now correctly check for libffi
  + Improved libffi-binding
  + Updated librep.sym for missing entries
  + Fixed an incomplete definition
  + Added -L$prefix to libs section of the .pc file
  + No C++ style comments in C code
* Fri Jul 31 2009 vuntz@novell.com
- Update to version 0.90.0:
  + Added UTF-8 Support!
  + Remove scheme and unscheme modules
  + Going on with code-cleanup
* Sun Jun 14 2009 vuntz@novell.com
- Clean up package.
- Update to 0.17.4.
